<?xml version="1.0"?>

<!--
 * ========================================================================
 * 
 * Copyright 2004 Carlos Sanchez.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * ========================================================================
-->

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--
  This takes a "mergeFile" parameter with the name of the file to merge in
-->

<xsl:output method="xml" indent="yes" encoding="iso8859_1"
    doctype-public="-//Sun Microsystems, Inc.//DTD Web Application 2.3//EN"
    doctype-system="http://java.sun.com/dtd/web-app_2_3.dtd"/>

<xsl:param name="mergeFile"/>

<!-- get xml from main file appending sections from mergeFile. -->
<xsl:template match="/web-app">
  <web-app>

    <!-- icon -->
    <xsl:choose>
      <xsl:when test="document($mergeFile)/web-app/icon">
        <xsl:copy-of select="document($mergeFile)/web-app/icon"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="icon"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- display-name -->
    <xsl:choose>
      <xsl:when test="document($mergeFile)/web-app/display-name">
        <xsl:copy-of select="document($mergeFile)/web-app/display-name"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="display-name"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- description -->
    <xsl:choose>
      <xsl:when test="document($mergeFile)/web-app/description">
        <xsl:copy-of select="document($mergeFile)/web-app/description"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="description"/>
      </xsl:otherwise>
    </xsl:choose>

    <!-- distributable -->
    <xsl:choose>
      <xsl:when test="document($mergeFile)/web-app/distributable">
        <xsl:copy-of select="document($mergeFile)/web-app/distributable"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="distributable"/>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates select="context-param"/>
    <xsl:copy-of select="document($mergeFile)/web-app/context-param"/>
    <xsl:apply-templates select="filter"/>
    <xsl:copy-of select="document($mergeFile)/web-app/filter"/>
    <xsl:apply-templates select="filter-mapping"/>
    <xsl:copy-of select="document($mergeFile)/web-app/filter-mapping"/>
    <xsl:apply-templates select="listener"/>
    <xsl:copy-of select="document($mergeFile)/web-app/listener"/>
    <xsl:apply-templates select="servlet"/>
    <xsl:copy-of select="document($mergeFile)/web-app/servlet"/>
    <xsl:apply-templates select="servlet-mapping"/>
    <xsl:copy-of select="document($mergeFile)/web-app/servlet-mapping"/>
    <xsl:apply-templates select="session-config"/>
    <xsl:copy-of select="document($mergeFile)/web-app/session-config"/>
    <xsl:apply-templates select="mime-mapping"/>
    <xsl:copy-of select="document($mergeFile)/web-app/mime-mapping"/>
    <xsl:apply-templates select="welcome-file-list"/>
    <xsl:copy-of select="document($mergeFile)/web-app/welcome-file-list"/>
    <xsl:apply-templates select="error-page"/>
    <xsl:copy-of select="document($mergeFile)/web-app/error-page"/>
    <xsl:apply-templates select="taglib"/>
    <xsl:copy-of select="document($mergeFile)/web-app/taglib"/>
    <xsl:apply-templates select="resource-env-ref"/>
    <xsl:copy-of select="document($mergeFile)/web-app/resource-env-ref"/>
    <xsl:apply-templates select="resource-ref"/>
    <xsl:copy-of select="document($mergeFile)/web-app/resource-ref"/>
    <xsl:apply-templates select="security-constraint"/>
    <xsl:copy-of select="document($mergeFile)/web-app/security-constraint"/>
    <xsl:apply-templates select="login-config"/>
    <xsl:copy-of select="document($mergeFile)/web-app/login-config"/>
    <xsl:apply-templates select="security-role"/>
    <xsl:copy-of select="document($mergeFile)/web-app/security-role"/>
    <xsl:apply-templates select="env-entry"/>
    <xsl:copy-of select="document($mergeFile)/web-app/env-entry"/>
    <xsl:apply-templates select="ejb-ref"/>
    <xsl:copy-of select="document($mergeFile)/web-app/ejb-ref"/>
    <xsl:apply-templates select="ejb-local-ref"/>
    <xsl:copy-of select="document($mergeFile)/web-app/ejb-local-ref"/>

  </web-app>
</xsl:template>

<xsl:template match="*">
  <xsl:for-each select="@*">
    <xsl:attribute name="{.}">
      <xsl:value-of select="."/>
    </xsl:attribute>
  </xsl:for-each>
  <xsl:copy-of select="."/>
</xsl:template>

</xsl:stylesheet>
