<%--
 * ========================================================================
 * 
 * Copyright 2004 Carlos Sanchez.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * ========================================================================
--%>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<%-- Tag libraries. --%>
<%@ include file="/common/taglibs.jsp" %>

<%-- Start of HTML. --%>

<html:html locale="true">

<%--
Struts manages locale in a different way as JSTL. So, fmt:setLocale is used to
set the same locale for fmt tags as the one used by Struts.

NOTES:

1. This tag must be used after Struts or a controller action has set Struts
locale. In this case, if locale was not set yet, html-el:html tag has set it.

2. Using fmt:setLocale with page scope does not work (maybe a bug in Jakarta
Standard TagLibs and/or Tomcat).

3. An alternative way to the use of fmt:setLocale, it would be to set JSTL
locale in the controller actions that set Struts locale, by setting the
attribute specified by the constant
"javax.servlet.jsp.jstl.core.Config.FMT_LOCALE" in the session. However, this
does not seem to work (maybe a bug in Jakarta Standard TagLibs and/or Tomcat).
--%>

<fmt:setLocale value='${sessionScope["org.apache.struts.action.LOCALE"]}'
    scope="session"/>

<%-- HTML header. --%>

<head>

  <tiles:useAttribute name="titleKey" scope="request"/>
  <tiles:insert name="title">
    <tiles:put name="titleKey" value="${titleKey}"/>
  </tiles:insert>
  
  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
  <meta name="author" content="Carlos Sanchez (carlossg@users.sourceforge.net)"/>

  <%-- Get Javascript List --%>
  <tiles:useAttribute id="scriptList" name="scripts" 
      classname="java.util.List" ignore="true"/>
  <c:forEach var="js" items="${scriptList}">
      <script type="text/javascript" src="<c:url value="${js}"/>"></script>
  </c:forEach>
  <%-- Validator Javascript. --%>
  <script language="JavaScript1.1" src='<c:url value="/scripts/validatorScripts.jsp"/>' 
      type="text/javascript"></script>
    
  <%-- Get List of Stylesheets --%>
  <tiles:useAttribute id="styleList" name="styles" 
      classname="java.util.List" ignore="true"/>
  <c:forEach var="css" items="${styleList}">
      <link rel="stylesheet" type="text/css" media="all"
          href="<c:url value="${css}"/>" /> 
  </c:forEach>

  <%-- Get List of Print Stylesheets --%>
  <tiles:useAttribute id="printList" name="printStyles" 
      classname="java.util.List" ignore="true"/>
  <c:forEach var="css" items="${printList}">
      <link rel="stylesheet" type="text/css" media="print"
          href="<c:url value="${css}"/>" /> 
  </c:forEach>

  <%-- Get List of Handheld Stylesheets --%>
  <tiles:useAttribute id="handheldList" name="handheldStyles" 
      classname="java.util.List" ignore="true"/>
  <c:forEach var="css" items="${handheldList}">
      <link rel="stylesheet" type="text/css" media="handheld"
          href="<c:url value="${css}"/>" /> 
  </c:forEach>

</head>

<%-- Start of HTML body. --%>

<body>

    <div id="screen">
        
        <div id="header">
            <tiles:insert name="header"/>
<%--
            <tiles:useAttribute name="header" scope="request"/>
            <c:import url='${requestScope.header}' context='${initParam.commonContext}'/>
--%>
        </div>
        
        <tiles:insert attribute="menu" ignore="true"/>

        <div id="content">
            <tiles:insert name="messages"/>
            <tiles:insert name="content"/>
<%--
            <tiles:useAttribute name="messages" scope="request"/>
            <c:import url='${messages}' context='${initParam.commonContext}'/>
            <tiles:useAttribute name="content" scope="request"/>
            <c:import url='${content}' context='${initParam.commonContext}'/>
--%>
        </div>

        <div id="footer">
            <tiles:insert name="footer"/>
<%--
            <tiles:useAttribute name="footer" scope="request"/>
            <c:import url='${footer}' context='${initParam.commonContext}'/>
--%>
        </div>

    </div>

<%-- End of HTML body. --%>

</body>

<%-- End of HTML. --%>

</html:html>
